@@ -8,7 +8,7 @@
 open Ctypes
 open PosixTypes
 
-module Struct_stubs(S : Cstubs.Types.TYPE) =
+module Struct_stubs(S : Ctypes.TYPE) =
 struct
   open S
 
