@@ -5,6 +5,7 @@
  * See the file LICENSE for details.
  *)
 
+[@@@warning "-33-35"]
 open Ctypes
 open OUnit2
 open Foreign
@@ -12,7 +13,7 @@ open Foreign
 let () =
   (* temporary workaround due to flexlink limitations *)
   if Sys.os_type = "Win32" then
-    ignore (Dl.(dlopen ~filename:"clib/libtest_functions.so" ~flags:[RTLD_NOW]))
+    ignore (Dl.(dlopen ~filename:"../clib/clib.so" ~flags:[RTLD_NOW]))
 
 
 let callback_with_pointers = Foreign.foreign "passing_pointers_to_callback"
@@ -136,7 +137,7 @@ let test_register_thread _ =
       else if Hashtbl.length htl_res <> succ n_threads then
         false
       else
-        Hashtbl.fold ( fun k v ac ->
+        Hashtbl.fold ( fun _k v ac ->
             if v = n_callback then ac else false
           ) htl_res true
     in
