@@ -12,7 +12,7 @@ open Ctypes
 module Struct_stubs = Types.Stubs(Generated_struct_bindings)
 
 
-let strip_whitespace = Str.(global_replace (regexp "[\n ]+") "")
+let strip_whitespace = Str.(global_replace (regexp "[\r\n ]+") "")
 
 let equal_ignoring_whitespace l r =
   strip_whitespace l = strip_whitespace r
@@ -66,12 +66,18 @@ let test_atomic_printing _ =
     assert_typ_printed_as "int32_t"
       int32_t;
 
+    assert_typ_printed_as "int32_t const"
+      (const int32_t);
+
     assert_typ_printed_as ~name:"f" "int64_t f"
       int64_t;
 
     assert_typ_printed_as "unsigned char"
       uchar;
 
+    assert_typ_printed_as "unsigned char volatile"
+      (volatile uchar);
+
     assert_typ_printed_as "_Bool"
       bool;
 
@@ -127,6 +133,15 @@ let test_pointer_printing _ =
     assert_typ_printed_as "unsigned long long **"
       (ptr (ptr ullong));
 
+    assert_typ_printed_as "unsigned long long const **"
+      (ptr (ptr (const ullong)));
+
+    assert_typ_printed_as "unsigned long long * const *"
+      (ptr (const (ptr ullong)));
+
+    assert_typ_printed_as "unsigned long long ** const"
+      (const (ptr (ptr ullong)));
+
     assert_typ_printed_as ~name:"b" "char *****b"
       (ptr (ptr (ptr (ptr (ptr char)))));
 
@@ -434,22 +449,22 @@ let test_ocaml_string_printing _ =
 let test_bigarray_signed_printing _ =
   begin
     assert_typ_printed_as "int8_t[1][3]"
-      (bigarray genarray [|1; 3|] Bigarray.int8_signed);
+      (bigarray genarray [|1; 3|] Bigarray_compat.int8_signed);
 
     assert_typ_printed_as "int16_t[3]"
-      (bigarray array1 3 Bigarray.int16_signed);
+      (bigarray array1 3 Bigarray_compat.int16_signed);
 
     assert_typ_printed_as "int32_t[5][6]"
-      (bigarray array2 (5, 6) Bigarray.int32);
+      (bigarray array2 (5, 6) Bigarray_compat.int32);
 
     assert_typ_printed_as "int64_t[7][8]"
-      (bigarray array2 (7, 8) Bigarray.int64);
+      (bigarray array2 (7, 8) Bigarray_compat.int64);
 
     assert_typ_printed_as "intnat[9][10]"
-      (bigarray array2 (9, 10) Bigarray.int);
+      (bigarray array2 (9, 10) Bigarray_compat.int);
 
     assert_typ_printed_as "intnat[13][14][15]"
-      (bigarray array3 (13, 14, 15) Bigarray.nativeint);
+      (bigarray array3 (13, 14, 15) Bigarray_compat.nativeint);
   end
 
 
@@ -461,10 +476,10 @@ let test_bigarray_unsigned_printing _ =
     "Unsigned bigarray elements currently indistinguishable from signed elements";
   begin
     assert_typ_printed_as "uint8_t[2]"
-      (bigarray array1 2 Bigarray.int8_unsigned);
+      (bigarray array1 2 Bigarray_compat.int8_unsigned);
 
     assert_typ_printed_as "uint16_t[4]"
-      (bigarray array1 4 Bigarray.int16_unsigned);
+      (bigarray array1 4 Bigarray_compat.int16_unsigned);
   end
 
 
@@ -474,16 +489,16 @@ let test_bigarray_unsigned_printing _ =
 let test_bigarray_float_printing _ =
   begin
     assert_typ_printed_as "float[10][100]"
-      (bigarray genarray [|10; 100|] Bigarray.float32);
+      (bigarray genarray [|10; 100|] Bigarray_compat.float32);
 
     assert_typ_printed_as "double[20][30][40]"
-      (bigarray genarray [|20; 30; 40|] Bigarray.float64);
+      (bigarray genarray [|20; 30; 40|] Bigarray_compat.float64);
 
     assert_typ_printed_as "float _Complex[16][17][18]"
-      (bigarray array3 (16, 17, 18) Bigarray.complex32);
+      (bigarray array3 (16, 17, 18) Bigarray_compat.complex32);
 
     assert_typ_printed_as "double _Complex[19][20][21]"
-      (bigarray array3 (19, 20, 21) Bigarray.complex64);
+      (bigarray array3 (19, 20, 21) Bigarray_compat.complex64);
   end
 
 
@@ -518,7 +533,7 @@ let test_view_printing _ =
   begin
     (* By default, views are printed as the underlying type *)
 
-    assert_typ_printed_as ~name:"a" "char *a"
+    assert_typ_printed_as ~name:"a" "char const* a"
       string;
 
     let v : unit typ = view ~read:(fun _ -> ()) ~write:(fun () () -> ())
